==> qtjambi-qt3dcore-5.15.6-sources.jar: io/qt/qt3d/core/QDynamicPropertyUpdatedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a dynamic property value is updated</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html">Qt3DCore::QDynamicPropertyUpdatedChange</a></p>
 */
public class QDynamicPropertyUpdatedChange extends io.qt.qt3d.core.QPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#QDynamicPropertyUpdatedChange">Qt3DCore::QDynamicPropertyUpdatedChange::QDynamicPropertyUpdatedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QDynamicPropertyUpdatedChange(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QDynamicPropertyUpdatedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#propertyName">Qt3DCore::QDynamicPropertyUpdatedChange::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#setPropertyName">Qt3DCore::QDynamicPropertyUpdatedChange::setPropertyName(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(io.qt.core.QByteArray name){
        setPropertyName_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(name));
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_cref_QByteArray(long __this__nativeId, long name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#setValue">Qt3DCore::QDynamicPropertyUpdatedChange::setValue(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#value">Qt3DCore::QDynamicPropertyUpdatedChange::value()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDynamicPropertyUpdatedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QDynamicPropertyUpdatedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a dynamic property value is updated</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html">Qt3DCore::QDynamicPropertyUpdatedChange</a></p>
 */
public class QDynamicPropertyUpdatedChange extends io.qt.qt3d.core.QPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#QDynamicPropertyUpdatedChange">Qt3DCore::QDynamicPropertyUpdatedChange::QDynamicPropertyUpdatedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QDynamicPropertyUpdatedChange(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QDynamicPropertyUpdatedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#propertyName">Qt3DCore::QDynamicPropertyUpdatedChange::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#setPropertyName">Qt3DCore::QDynamicPropertyUpdatedChange::setPropertyName(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(io.qt.core.QByteArray name){
        setPropertyName_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(name));
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_cref_QByteArray(long __this__nativeId, long name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#setValue">Qt3DCore::QDynamicPropertyUpdatedChange::setValue(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qdynamicpropertyupdatedchange.html#value">Qt3DCore::QDynamicPropertyUpdatedChange::value()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDynamicPropertyUpdatedChange(QPrivateConstructor p) { super(p); } 
    
}
